@@ -1,6 +1,7 @@
 __all__ = 'SUPPORTED',
 try:
     import translators
+    from fastdub.translator import subs_translate
 
     SERVICES = [i[1:] for i in dir(translators.apis) if i.startswith('_') and not i.startswith('__')]
 
@@ -11,4 +12,4 @@ except ImportError:
     SUPPORTED = False
 else:
     SUPPORTED = True
-    __all__ += 'translators', 'SERVICES', 'get_service_by_name'
+    __all__ += ('translators', 'SERVICES', 'get_service_by_name', 'subs_translate')
